# -*- coding: utf-8 -*-
import os
import re
from setuptools import setup, find_packages


setup_kwargs = {}

with open('README.md') as f:
    setup_kwargs['long_description'] = f.read()

# version from file
with open(os.path.join('xbanalysis', '_version.py')) as f:
    mo = re.search(r"^__version__ = ['\"]([^'\"]*)['\"]",
                   f.read(), re.MULTILINE)
    if mo:
        setup_kwargs['version'] = mo.group(1)

setup(
    name='xbanalysis',
    description='XBA problem generation from SBML metabolic/kinetic models',
    author='Peter Schubert',
    author_email='peter.schubert@hhu.de',
    url='https://gitlab.cs.uni-duesseldorf.de/schubert/xbanalysis',
    project_urls={
        "Source Code": 'https://gitlab.cs.uni-duesseldorf.de/schubert/xbanalysis',
        "Bug Tracker":
        'https://gitlab.cs.uni-duesseldorf.de/schubert/xbanalysis/-/issues'},
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: GNU Lesser General Public License v3 (LGPLv3)",
        "Operating System :: OS Independent",
        "Topic :: Scientific/Engineering :: Bio-Informatics",
    ],
    license='GPLv3',
    long_description_content_type='text/markdown',
    packages=find_packages(exclude='docs'),
    install_requires=['pandas>=1.3.0',
                      'numpy >= 1.20.0',
                      'sbmlxdf>=0.2.5'],
    python_requires=">=3.7",
    keywords=['modeling', 'standardization', 'SBML'],
    **setup_kwargs
)
